@@ -101,6 +101,13 @@ func (c *Client) Dir(ctx context.Context, input DirInput) (migrate.Dir, error) {
 }
 
 type (
+	// DeployContextInput is an input type for describing the context in which
+	// `migrate-apply` was used. For example, a GitHub Action with version v1.2.3
+	DeployContextInput struct {
+		TriggerType    string `json:"triggerType,omitempty"`
+		TriggerVersion string `json:"triggerVersion,omitempty"`
+	}
+
 	// ReportMigrationSetInput represents the input type for reporting a set of migration deployments.
 	ReportMigrationSetInput struct {
 		ID        string                 `json:"id"`
@@ -110,6 +117,7 @@ type (
 		Error     *string                `json:"error,omitempty"`
 		Log       []ReportStep           `json:"log,omitempty"`
 		Completed []ReportMigrationInput `json:"completed,omitempty"`
+		Context   *DeployContextInput    `json:"context,omitempty"`
 	}
 
 	// ReportMigrationInput represents an input type for reporting a migration deployments.
@@ -127,6 +135,7 @@ type (
 		Error          *string             `json:"error,omitempty"`
 		Files          []DeployedFileInput `json:"files"`
 		Log            string              `json:"log"`
+		Context        *DeployContextInput `json:"context,omitempty"`
 	}
 
 	// DeployedTargetInput represents the input type for a deployed target.
@@ -138,13 +147,29 @@ type (
 
 	// DeployedFileInput represents the input type for a deployed file.
 	DeployedFileInput struct {
-		Name      string          `json:"name"`
-		Content   string          `json:"content"`
-		StartTime time.Time       `json:"startTime"`
-		EndTime   time.Time       `json:"endTime"`
-		Skipped   int             `json:"skipped"`
-		Applied   int             `json:"applied"`
-		Error     *StmtErrorInput `json:"error,omitempty"`
+		Name      string            `json:"name"`
+		Content   string            `json:"content"`
+		StartTime time.Time         `json:"startTime"`
+		EndTime   time.Time         `json:"endTime"`
+		Skipped   int               `json:"skipped"`
+		Applied   int               `json:"applied"`
+		Checks    []FileChecksInput `json:"checks"`
+		Error     *StmtErrorInput   `json:"error,omitempty"`
+	}
+
+	// FileChecksInput represents the input type for a file checks.
+	FileChecksInput struct {
+		Name   string           `json:"name"`
+		Start  time.Time        `json:"start"`
+		End    time.Time        `json:"end"`
+		Checks []CheckStmtInput `json:"checks"`
+		Error  *StmtErrorInput  `json:"error,omitempty"`
+	}
+
+	// CheckStmtInput represents the input type for a statement check.
+	CheckStmtInput struct {
+		Stmt  string  `json:"stmt"`
+		Error *string `json:"error,omitempty"`
 	}
 
 	// StmtErrorInput represents the input type for a statement error.
