@@ -75,6 +75,17 @@ func TestCLI_Version(t *testing.T) {
 	}
 }
 
+func TestVars_String(t *testing.T) {
+	var vs Vars
+	require.Equal(t, "[]", vs.String())
+	require.NoError(t, vs.Set("a=b"))
+	require.Equal(t, "[a:b]", vs.String())
+	require.NoError(t, vs.Set("b=c"))
+	require.Equal(t, "[a:b, b:c]", vs.String())
+	require.NoError(t, vs.Set("a=d"))
+	require.Equal(t, "[a:[b, d], b:c]", vs.String(), "multiple values of the same key: --var url=<one> --var url=<two>")
+}
+
 func runCmd(cmd *cobra.Command, args ...string) (string, error) {
 	return runCmdContext(context.Background(), cmd, args...)
 }
@@ -98,17 +109,17 @@ func openSQLite(t *testing.T, seed string) string {
 	f, err := os.CreateTemp("", "sqlite.db")
 	require.NoError(t, err)
 	t.Cleanup(func() {
-		os.Remove(f.Name())
+		require.NoError(t, os.Remove(f.Name()))
 	})
 	dsn := fmt.Sprintf("file:%s?cache=shared&_fk=1", f.Name())
 	db, err := sql.Open("sqlite3", dsn)
 	require.NoError(t, err)
 	t.Cleanup(func() {
-		db.Close()
+		require.NoError(t, db.Close())
 	})
 	drv, err := sqlite.Open(db)
 	require.NoError(t, err)
-	if len(seed) > 0 {
+	if seed != "" {
 		_, err := drv.ExecContext(context.Background(), seed)
 		require.NoError(t, err)
 	}
