@@ -1878,6 +1878,24 @@ func TestMigrate_Validate(t *testing.T) {
 	// Should fail since the files are not compatible with SQLite.
 	_, err = runCmd(migrateValidateCmd(), "--dir", "file://testdata/mysql", "--dev-url", openSQLite(t, ""))
 	require.Error(t, err)
+
+	// Will report detailed information when there is a checksum mismatch.
+	p = t.TempDir()
+	require.NoError(t, os.WriteFile(filepath.Join(p, "1_initial.sql"), []byte("create table t1 (c1 int)"), 0644))
+	s, err = runCmd(migrateValidateCmd(), "--dir", "file://"+p)
+	require.ErrorIs(t, err, migrate.ErrChecksumNotFound)
+	require.Contains(t, s, "You have a checksum error")
+	_, err = runCmd(migrateHashCmd(), "--dir", "file://"+p)
+	require.NoError(t, err)
+	require.NoError(t, os.WriteFile(filepath.Join(p, "2_second.sql"), []byte("create table t2 (c2 int)"), 0644))
+	s, err = runCmd(migrateValidateCmd(), "--dir", "file://"+p)
+	csErr := &migrate.ChecksumError{}
+	require.ErrorAs(t, err, &csErr)
+	require.Equal(t, 2, csErr.Line)
+	require.Equal(t, "2_second.sql", csErr.File)
+	require.Equal(t, migrate.ReasonAdded, csErr.Reason)
+	require.Contains(t, s, "You have a checksum error")
+	require.Contains(t, s, "L 2: 2_second.sql was added")
 }
 
 func TestMigrate_Hash(t *testing.T) {
@@ -1940,7 +1958,21 @@ func TestMigrate_Lint(t *testing.T) {
 		"--latest", "1",
 	)
 	require.Error(t, err)
-	require.Equal(t, "2.sql: destructive changes detected:\n\n\tL1: Dropping table \"t\"\n\n", s)
+	require.Regexp(t, `Analyzing changes from version 1 to 2 \(1 migration in total\):
+
+  -- analyzing version 2
+    -- destructive changes detected:
+      -- L1: Dropping table "t" https://atlasgo.io/lint/analyzers#DS102
+    -- suggested fix:
+      -> Add a pre-migration check to ensure table "t" is empty before dropping it
+  -- ok \(.+\)
+
+  -------------------------
+  -- .+
+  -- 1 version with errors
+  -- 1 schema change
+  -- 1 diagnostic
+`, s)
 	s, err = runCmd(
 		migrateLintCmd(),
 		"--dir", "file://"+p,
@@ -1976,7 +2008,21 @@ lint {
 			"-c", "file://"+cfg,
 		)
 		require.NoError(t, err)
-		require.Equal(t, "2.sql: destructive changes detected:\n\n\tL1: Dropping table \"t\"\n\n", s)
+		require.Regexp(t, `Analyzing changes from version 1 to 2 \(1 migration in total\):
+
+  -- analyzing version 2
+    -- destructive changes detected:
+      -- L1: Dropping table "t" https://atlasgo.io/lint/analyzers#DS102
+    -- suggested fix:
+      -> Add a pre-migration check to ensure table "t" is empty before dropping it
+  -- ok \(.+\)
+
+  -------------------------
+  -- .+
+  -- 1 version with warnings
+  -- 1 schema change
+  -- 1 diagnostic
+`, s)
 
 		cmd = migrateCmd()
 		cmd.AddCommand(migrateLintCmd())
@@ -1988,7 +2034,21 @@ lint {
 			"--var", "error=true",
 		)
 		require.Error(t, err)
-		require.Equal(t, "2.sql: destructive changes detected:\n\n\tL1: Dropping table \"t\"\n\n", s)
+		require.Regexp(t, `Analyzing changes from version 1 to 2 \(1 migration in total\):
+
+  -- analyzing version 2
+    -- destructive changes detected:
+      -- L1: Dropping table "t" https://atlasgo.io/lint/analyzers#DS102
+    -- suggested fix:
+      -> Add a pre-migration check to ensure table "t" is empty before dropping it
+  -- ok (.+)
+
+  -------------------------
+  -- .+
+  -- 1 version with errors
+  -- 1 schema change
+  -- 1 diagnostic
+`, s)
 	})
 
 	// Change files to golang-migrate format.
@@ -2024,7 +2084,14 @@ lint {
 		"--latest", "1",
 	)
 	require.Error(t, err)
-	require.Equal(t, "2.up.sql: executing statement: near \"BORING\": syntax error\n", s)
+	require.Regexp(t, `Analyzing changes from version 1.up to 2.up \(1 migration in total\):
+
+  Error: executing statement: near "BORING": syntax error
+
+  -------------------------
+  -- .+
+  -- 1 version with errors
+`, s)
 }
 
 const testSchema = `
