@@ -10,6 +10,8 @@ import (
 	"os"
 	"path/filepath"
 	"reflect"
+	"strings"
+	"sync"
 
 	"ariga.io/atlas/cmd/atlas/internal/cloudapi"
 	"ariga.io/atlas/cmd/atlas/internal/cmdext"
@@ -25,20 +27,6 @@ import (
 	"github.com/zclconf/go-cty/cty/function"
 )
 
-type loadConfig struct {
-	inputValues map[string]cty.Value
-}
-
-// LoadOption configures the LoadEnv function.
-type LoadOption func(*loadConfig)
-
-// WithInput is a LoadOption that sets the input values for the LoadEnv function.
-func WithInput(values map[string]cty.Value) LoadOption {
-	return func(config *loadConfig) {
-		config.inputValues = values
-	}
-}
-
 type (
 	// Project represents an atlas.hcl project config file.
 	Project struct {
@@ -88,6 +76,7 @@ type (
 		Dir             string `spec:"dir"`
 		Format          string `spec:"format"`
 		Baseline        string `spec:"baseline"`
+		ExecOrder       string `spec:"exec_order"`
 		LockTimeout     string `spec:"lock_timeout"`
 		RevisionsSchema string `spec:"revisions_schema"`
 	}
@@ -104,6 +93,8 @@ type (
 			// Base configures the --git-base option.
 			Base string `spec:"base"`
 		} `spec:"git"`
+		// Review defines when Atlas will ask the user to review and approve the changes.
+		Review string `spec:"review"`
 		schemahcl.DefaultExtension
 	}
 
@@ -122,6 +113,7 @@ type (
 		AddTable         bool `spec:"add_table"`
 		DropTable        bool `spec:"drop_table"`
 		ModifyTable      bool `spec:"modify_table"`
+		RenameTable      bool `spec:"rename_table"`
 		AddColumn        bool `spec:"add_column"`
 		DropColumn       bool `spec:"drop_column"`
 		ModifyColumn     bool `spec:"modify_column"`
@@ -131,6 +123,22 @@ type (
 		AddForeignKey    bool `spec:"add_foreign_key"`
 		DropForeignKey   bool `spec:"drop_foreign_key"`
 		ModifyForeignKey bool `spec:"modify_foreign_key"`
+		AddView          bool `spec:"add_view"`
+		DropView         bool `spec:"drop_view"`
+		ModifyView       bool `spec:"modify_view"`
+		RenameView       bool `spec:"rename_view"`
+		AddFunc          bool `spec:"add_func"`
+		DropFunc         bool `spec:"drop_func"`
+		ModifyFunc       bool `spec:"modify_func"`
+		RenameFunc       bool `spec:"rename_func"`
+		AddProc          bool `spec:"add_proc"`
+		DropProc         bool `spec:"drop_proc"`
+		ModifyProc       bool `spec:"modify_proc"`
+		RenameProc       bool `spec:"rename_proc"`
+		AddTrigger       bool `spec:"add_trigger"`
+		DropTrigger      bool `spec:"drop_trigger"`
+		ModifyTrigger    bool `spec:"modify_trigger"`
+		RenameTrigger    bool `spec:"rename_trigger"`
 	}
 
 	// Format represents the output formatting configuration of an environment.
@@ -155,6 +163,39 @@ type (
 	}
 )
 
+// envScheme defines the scheme that can be used to reference env attributes.
+const envAttrScheme = "env"
+
+// VarFromURL returns the string variable (env attribute) from the URL.
+func (e *Env) VarFromURL(s string) (string, error) {
+	u, err := url.Parse(s)
+	if err != nil {
+		return "", err
+	}
+	if u.Host == "" || u.Path != "" || u.RawQuery != "" {
+		return "", fmt.Errorf("invalid env:// variable %q", s)
+	}
+	var sv string
+	switch u.Host {
+	case "url":
+		sv = e.URL
+	case "dev":
+		sv = e.DevURL
+	default:
+		attr, ok := e.Attr(u.Host)
+		if !ok {
+			return "", fmt.Errorf("env://%s (attribute) not found in env.%s", u.Host, e.Name)
+		}
+		if sv, err = attr.String(); err != nil {
+			return "", fmt.Errorf("env://%s: %w", u.Host, err)
+		}
+	}
+	if strings.HasPrefix(sv, envAttrScheme+"://") {
+		return "", fmt.Errorf("env://%s (attribute) cannot reference another env://", s)
+	}
+	return sv, nil
+}
+
 // support backward compatibility with the 'log' attribute.
 func (e *Env) remainedLog() error {
 	r, ok := e.Remain().Resource("log")
@@ -193,6 +234,9 @@ func (l *Lint) Extend(global *Lint) *Lint {
 	if l == nil {
 		return global
 	}
+	if l.Review == "" {
+		l.Review = global.Review
+	}
 	if l.Format == "" {
 		l.Format = global.Format
 	}
@@ -275,10 +319,14 @@ func (d *Diff) Options() (opts []schema.DiffOption) {
 	)
 	for _, c := range []schema.Change{
 		&schema.AddSchema{}, &schema.DropSchema{}, &schema.ModifySchema{},
-		&schema.AddTable{}, &schema.DropTable{}, &schema.ModifyTable{},
-		&schema.AddColumn{}, &schema.DropColumn{}, &schema.ModifyColumn{},
-		&schema.AddIndex{}, &schema.DropIndex{}, &schema.ModifyIndex{},
-		&schema.AddForeignKey{}, &schema.DropForeignKey{}, &schema.ModifyForeignKey{},
+		&schema.AddView{}, &schema.DropView{}, &schema.ModifyView{}, &schema.RenameView{},
+		&schema.AddFunc{}, &schema.DropFunc{}, &schema.ModifyFunc{}, &schema.RenameFunc{},
+		&schema.AddProc{}, &schema.DropProc{}, &schema.ModifyProc{}, &schema.RenameProc{},
+		&schema.AddTrigger{}, &schema.DropTrigger{}, &schema.ModifyTrigger{}, &schema.RenameTrigger{},
+		&schema.AddTable{}, &schema.DropTable{}, &schema.ModifyTable{}, &schema.RenameTable{},
+		&schema.AddColumn{}, &schema.DropColumn{}, &schema.ModifyColumn{}, &schema.AddIndex{},
+		&schema.DropIndex{}, &schema.ModifyIndex{}, &schema.AddForeignKey{}, &schema.DropForeignKey{},
+		&schema.ModifyForeignKey{},
 	} {
 		if rt := reflect.TypeOf(c).Elem(); rv.FieldByName(rt.Name()).Bool() {
 			changes = append(changes, c)
@@ -336,22 +384,29 @@ func (e *Env) asMap() (map[string]string, error) {
 }
 
 // EnvByName parses and returns the project configuration with selected environments.
-func EnvByName(cmd *cobra.Command, name string, opts ...LoadOption) (*Project, []*Env, error) {
+func EnvByName(cmd *cobra.Command, name string, vars map[string]cty.Value) (*Project, []*Env, error) {
+	envs := make(map[string][]*Env)
+	defer func() {
+		setEnvs(cmd.Context(), envs[name])
+	}()
+	if p, e, ok := envsCache.load(GlobalFlags.ConfigURL, name, vars); ok {
+		return p, e, nil
+	}
 	u, err := url.Parse(GlobalFlags.ConfigURL)
 	if err != nil {
 		return nil, nil, err
 	}
 	if u.Scheme != "file" {
-		return nil, nil, fmt.Errorf("unsupported project file driver %q", u.Scheme)
+		return nil, nil, fmt.Errorf("unsupported config file driver %q", u.Scheme)
 	}
 	path := filepath.Join(u.Host, u.Path)
 	if _, err := os.Stat(path); err != nil {
 		if os.IsNotExist(err) {
-			err = fmt.Errorf("project file %q was not found: %w", path, err)
+			err = fmt.Errorf("config file %q was not found: %w", path, err)
 		}
 		return nil, nil, err
 	}
-	project, err := parseConfig(path, name, opts...)
+	project, err := parseConfig(path, name, vars)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -367,7 +422,6 @@ func EnvByName(cmd *cobra.Command, name string, opts ...LoadOption) (*Project, [
 	if err := project.Lint.remainedLog(); err != nil {
 		return nil, nil, err
 	}
-	envs := make(map[string][]*Env)
 	for _, e := range project.Envs {
 		if e.Name == "" {
 			return nil, nil, fmt.Errorf("all envs must have names on file %q", path)
@@ -388,6 +442,7 @@ func EnvByName(cmd *cobra.Command, name string, opts ...LoadOption) (*Project, [
 		}
 		envs[e.Name] = append(envs[e.Name], e)
 	}
+	envsCache.store(GlobalFlags.ConfigURL, name, vars, project, envs[name])
 	switch {
 	case name == "":
 		// If no env was selected,
@@ -400,17 +455,42 @@ func EnvByName(cmd *cobra.Command, name string, opts ...LoadOption) (*Project, [
 	}
 }
 
+type (
+	envCacheK struct {
+		path, env, vars string
+	}
+	envCacheV struct {
+		p *Project
+		e []*Env
+	}
+	envCache struct {
+		sync.RWMutex
+		m map[envCacheK]envCacheV
+	}
+)
+
+var envsCache = &envCache{m: make(map[envCacheK]envCacheV)}
+
+func (c *envCache) load(path, env string, vars Vars) (*Project, []*Env, bool) {
+	c.RLock()
+	v, ok := c.m[envCacheK{path: path, env: env, vars: vars.String()}]
+	c.RUnlock()
+	return v.p, v.e, ok
+}
+
+func (c *envCache) store(path, env string, vars Vars, p *Project, e []*Env) {
+	c.Lock()
+	c.m[envCacheK{path: path, env: env, vars: vars.String()}] = envCacheV{p: p, e: e}
+	c.Unlock()
+}
+
 const (
 	blockEnv          = "env"
 	refAtlas          = "atlas"
 	defaultConfigPath = "file://atlas.hcl"
 )
 
-func parseConfig(path, env string, opts ...LoadOption) (*Project, error) {
-	loadCfg := &loadConfig{}
-	for _, f := range opts {
-		f(loadCfg)
-	}
+func parseConfig(path, env string, vars map[string]cty.Value) (*Project, error) {
 	pr, err := partialParse(path, env)
 	if err != nil {
 		return nil, err
@@ -424,9 +504,12 @@ func parseConfig(path, env string, opts ...LoadOption) (*Project, error) {
 	}
 	state := schemahcl.New(
 		append(
-			cmdext.DataSources,
+			append(cmdext.SpecOptions, specOptions...),
 			cfg.InitBlock(),
 			schemahcl.WithScopedEnums("env.migration.format", cmdmigrate.Formats...),
+			schemahcl.WithScopedEnums("env.migration.exec_order", "LINEAR", "LINEAR_SKIP", "NON_LINEAR"),
+			schemahcl.WithScopedEnums("env.lint.review", ReviewModes...),
+			schemahcl.WithScopedEnums("lint.review", ReviewModes...),
 			schemahcl.WithVariables(map[string]cty.Value{
 				refAtlas: cty.ObjectVal(map[string]cty.Value{
 					blockEnv: cty.StringVal(env),
@@ -450,7 +533,7 @@ func parseConfig(path, env string, opts ...LoadOption) (*Project, error) {
 		)...,
 	)
 	p := &Project{Lint: &Lint{}, Diff: &Diff{}, cfg: cfg}
-	if err := state.Eval(pr, p, loadCfg.inputValues); err != nil {
+	if err := state.Eval(pr, p, vars); err != nil {
 		return nil, err
 	}
 	for _, e := range p.Envs {
@@ -497,3 +580,12 @@ func partialParse(path, env string) (*hclparse.Parser, error) {
 	}
 	return parser, nil
 }
+
+// Review modes for 'schema apply'.
+const (
+	ReviewAlways  = "ALWAYS"  // Always review changes. The default mode.
+	ReviewWarning = "WARNING" // Review changes only if there are any diagnostics (including warnings).
+	ReviewError   = "ERROR"   // Review changes only if there are severe diagnostics (error level).
+)
+
+var ReviewModes = []string{ReviewAlways, ReviewWarning, ReviewError}
