@@ -39,9 +39,11 @@ import (
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/gocty"
 	"gocloud.dev/runtimevar"
+	_ "gocloud.dev/runtimevar/awsparamstore"
 	_ "gocloud.dev/runtimevar/awssecretsmanager"
 	_ "gocloud.dev/runtimevar/constantvar"
 	_ "gocloud.dev/runtimevar/filevar"
+	_ "gocloud.dev/runtimevar/gcpruntimeconfig"
 	_ "gocloud.dev/runtimevar/gcpsecretmanager"
 	_ "gocloud.dev/runtimevar/httpvar"
 )
@@ -156,7 +158,7 @@ func AWSRDSToken(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error
 // GCPCloudSQLToken exposes a CloudSQL token as a schemahcl datasource.
 //
 //	data "gcp_cloudsql_token" "hello" {}
-func GCPCloudSQLToken(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
+func GCPCloudSQLToken(_ *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
 	errorf := blockError("data.gcp_cloudsql_token", block)
 	bgctx := context.Background()
 	ts, err := google.DefaultTokenSource(bgctx, sqladmin.SqlserviceAdminScope)
