@@ -1,7 +1,7 @@
 /** @type {import('@docusaurus/types').DocusaurusConfig} */
 module.exports = {
-  title: 'Atlas | Open-source database schema management tool',
-  tagline: 'Manage your database schemas with Atlas CLI',
+  title: 'Atlas | Manage your database schema as code',
+  tagline: 'Manage your database schema as code',
   url: 'https://atlasgo.io',
   baseUrl: '/',
   onBrokenLinks: 'throw',
@@ -125,7 +125,7 @@ module.exports = {
           "title": "Atlas Cloud",
           "items": [
             {"label": "Discover Atlas Cloud", "to": "https://atlasgo.cloud/?utm_term=footer"},
-            {"label": "Live Demo", "to": "https://gh.atlasgo.cloud/dirs?utm_term=footer"},
+            {"label": "Live Demo", "to": "https://gh.atlasgo.cloud/projects?utm_term=footer"},
             {"label": "Sign Up", "to": "https://auth.atlasgo.cloud/signup?utm_term=footer"},
           ]
         },
@@ -147,8 +147,8 @@ module.exports = {
       `,
     },
     announcementBar: {
-      id: 'announcementBar-9', // Increment on change
-      content: `<strong>Atlas v0.19: Pre-migration Checks, Schema Doc, MSSQL Triggers, and more. </strong><a class="cta" href="https://atlasgo.io/blog/2024/02/02/atlas-v-0-19">Read it here</a>`,
+      id: 'announcementBar-10', // Increment on change
+      content: `<strong>Upcoming Pricing Changes to Atlas Cloud. </strong><a class="cta" href="https://atlasgo.io/blog/2024/03/03/pricing-change">Read all about it here.</a>`,
       isCloseable: true,
       backgroundColor: '#0084ec',
       textColor: '#fff',
