@@ -18,15 +18,24 @@ import (
 	"text/template"
 )
 
-// Job defines an integration job to run.
-type Job struct {
-	Version string   // version to test (passed to go test as flag which database dialect/version)
-	Image   string   // name of service
-	Regex   string   // run regex
-	Env     []string // env of service
-	Ports   []string // port mappings
-	Options []string // other options
-}
+type (
+	// Step defines a step to run.
+	Step struct {
+		Name   string
+		Action string
+		With   []string
+	}
+	// Job defines an integration job to run.
+	Job struct {
+		Version string   // version to test (passed to go test as flag which database dialect/version)
+		Image   string   // name of service
+		Regex   string   // run regex
+		Env     []string // env of service
+		Ports   []string // port mappings
+		Options []string // other options
+		Steps   []Step   // extra steps to run
+	}
+)
 
 var (
 	//go:embed *.tmpl
