@@ -110,6 +110,21 @@ func TestResource(t *testing.T) {
 	require.EqualValues(t, f, string(buf))
 }
 
+func TestInvalidRefs(t *testing.T) {
+	var doc struct {
+		Tables []struct {
+			Name string `spec:",name"`
+			Refs []*Ref `spec:"ref"`
+		}
+	}
+	err := New().EvalBytes([]byte(`
+table "bar" {
+  refs = [table]
+}
+`), &doc, nil)
+	require.EqualError(t, err, ":3,3-17: invalid reference used in refs")
+}
+
 func ExampleUnmarshal() {
 	f := `
 show "seinfeld" {
@@ -865,7 +880,7 @@ func TestTypeLabelBlock(t *testing.T) {
 				callT++
 				return cty.ObjectVal(map[string]cty.Value{"url": cty.StringVal("driver://" + v.AsString())}), nil
 			}),
-			WithTypeLabelBlock("driver", "not_called", func(ctx *hcl.EvalContext, b *hclsyntax.Block) (cty.Value, error) {
+			WithTypeLabelBlock("driver", "not_called", func(*hcl.EvalContext, *hclsyntax.Block) (cty.Value, error) {
 				t.Fatal("should not be called")
 				return cty.NilVal, nil
 			}),
