@@ -20,3 +20,13 @@ func (*Diff) triggerDiff(_, _ interface {
 }, _, _ []*schema.Trigger, _ *schema.DiffOptions) ([]schema.Change, error) {
 	return nil, nil // unimplemented.
 }
+
+// funcDep returns true if f1 depends on f2.
+func funcDep(_, _ *schema.Func) bool {
+	return false // unimplemented.
+}
+
+// procDep returns true if p1 depends on p2.
+func procDep(_, _ *schema.Proc) bool {
+	return false // unimplemented.
+}
