@@ -30,9 +30,11 @@ func (i *inspect) InspectRealm(ctx context.Context, opts *schema.InspectRealmOpt
 	if opts == nil {
 		opts = &schema.InspectRealmOption{}
 	}
-	r := schema.NewRealm(schemas...).SetCharset(i.charset).SetCollation(i.collate)
+	var (
+		mode = sqlx.ModeInspectRealm(opts)
+		r    = schema.NewRealm(schemas...).SetCharset(i.charset).SetCollation(i.collate)
+	)
 	if len(schemas) > 0 {
-		mode := sqlx.ModeInspectRealm(opts)
 		if mode.Is(schema.InspectTables) {
 			if err := i.inspectTables(ctx, r, nil); err != nil {
 				return nil, err
@@ -49,8 +51,13 @@ func (i *inspect) InspectRealm(ctx context.Context, opts *schema.InspectRealmOpt
 				return nil, err
 			}
 		}
+		if mode.Is(schema.InspectTriggers) {
+			if err := i.inspectTriggers(ctx, r, nil); err != nil {
+				return nil, err
+			}
+		}
 	}
-	return sqlx.ExcludeRealm(r, opts.Exclude)
+	return schema.ExcludeRealm(r, opts.Exclude)
 }
 
 // InspectSchema returns schema descriptions of the tables in the given schema.
@@ -69,24 +76,32 @@ func (i *inspect) InspectSchema(ctx context.Context, name string, opts *schema.I
 	if opts == nil {
 		opts = &schema.InspectOptions{}
 	}
-	r := schema.NewRealm(schemas...).SetCharset(i.charset).SetCollation(i.collate)
-	if sqlx.ModeInspectSchema(opts).Is(schema.InspectTables) {
+	var (
+		mode = sqlx.ModeInspectSchema(opts)
+		r    = schema.NewRealm(schemas...).SetCharset(i.charset).SetCollation(i.collate)
+	)
+	if mode.Is(schema.InspectTables) {
 		if err := i.inspectTables(ctx, r, opts); err != nil {
 			return nil, err
 		}
 		sqlx.LinkSchemaTables(schemas)
 	}
-	if sqlx.ModeInspectSchema(opts).Is(schema.InspectViews) {
+	if mode.Is(schema.InspectViews) {
 		if err := i.inspectViews(ctx, r, opts); err != nil {
 			return nil, err
 		}
 	}
-	if sqlx.ModeInspectSchema(opts).Is(schema.InspectFuncs) {
+	if mode.Is(schema.InspectFuncs) {
 		if err := i.inspectFuncs(ctx, r, opts); err != nil {
 			return nil, err
 		}
 	}
-	return sqlx.ExcludeSchema(r.Schemas[0], opts.Exclude)
+	if mode.Is(schema.InspectTriggers) {
+		if err := i.inspectTriggers(ctx, r, nil); err != nil {
+			return nil, err
+		}
+	}
+	return schema.ExcludeSchema(r.Schemas[0], opts.Exclude)
 }
 
 func (i *inspect) inspectTables(ctx context.Context, r *schema.Realm, opts *schema.InspectOptions) error {
@@ -752,9 +767,12 @@ ORDER BY
 	TABLE_SCHEMA, TABLE_NAME`
 
 	// Query to list table check constraints.
-	myChecksQuery  = `SELECT t1.TABLE_NAME, t1.CONSTRAINT_NAME, t2.CHECK_CLAUSE, t1.ENFORCED` + checksQuery
-	marChecksQuery = `SELECT t1.TABLE_NAME, t1.CONSTRAINT_NAME, t2.CHECK_CLAUSE, "YES" AS ENFORCED` + checksQuery
-	checksQuery    = `
+	myChecksQuery = `
+SELECT
+	t1.TABLE_NAME,
+	t1.CONSTRAINT_NAME,
+	t2.CHECK_CLAUSE,
+	t1.ENFORCED
 FROM
 	INFORMATION_SCHEMA.TABLE_CONSTRAINTS AS t1
 	JOIN INFORMATION_SCHEMA.CHECK_CONSTRAINTS AS t2
@@ -765,8 +783,23 @@ WHERE
 	AND t1.TABLE_SCHEMA = ?
 	AND t1.TABLE_NAME IN (%s)
 ORDER BY
-	t1.CONSTRAINT_NAME`
+	t1.TABLE_NAME, t1.CONSTRAINT_NAME
+`
 
+	marChecksQuery = `
+SELECT
+	TABLE_NAME,
+	CONSTRAINT_NAME,
+	CHECK_CLAUSE,
+	"YES" AS ENFORCED
+FROM
+	INFORMATION_SCHEMA.CHECK_CONSTRAINTS
+WHERE
+	CONSTRAINT_SCHEMA = ?
+	AND TABLE_NAME IN (%s)
+ORDER BY
+	TABLE_NAME, CONSTRAINT_NAME
+`
 	// Query to list table foreign keys.
 	fksQuery = `
 SELECT
