@@ -368,12 +368,12 @@ func TestPlanChanges(t *testing.T) {
 		},
 		{
 			changes: []schema.Change{
-				&schema.DropObject{O: &schema.EnumType{T: "status", Values: []string{"on", "off"}, Schema: schema.New("public")}},
 				&schema.DropTable{T: schema.NewTable("logs").
 					AddColumns(
 						schema.NewColumn("status").SetType(&schema.EnumType{T: "status", Values: []string{"on", "off"}, Schema: schema.New("public")}),
 					),
 				},
+				&schema.DropObject{O: &schema.EnumType{T: "status", Values: []string{"on", "off"}, Schema: schema.New("public")}},
 				&schema.DropObject{O: &schema.EnumType{T: "state", Values: []string{"on", "off"}, Schema: schema.New("public")}},
 			},
 			wantPlan: &migrate.Plan{
@@ -872,13 +872,6 @@ func TestPlanChanges(t *testing.T) {
 		},
 		{
 			changes: []schema.Change{
-				&schema.DropObject{
-					O: &schema.EnumType{
-						T:      "state",
-						Values: []string{"on", "off"},
-						Schema: schema.New("public"),
-					},
-				},
 				&schema.DropTable{
 					T: schema.NewTable("users").
 						SetSchema(schema.New("public")).
@@ -887,6 +880,13 @@ func TestPlanChanges(t *testing.T) {
 							schema.NewEnumColumn("status", schema.EnumName("status"), schema.EnumValues("on", "off"), schema.EnumSchema(schema.New("public"))),
 						),
 				},
+				&schema.DropObject{
+					O: &schema.EnumType{
+						T:      "state",
+						Values: []string{"on", "off"},
+						Schema: schema.New("public"),
+					},
+				},
 				&schema.DropObject{
 					O: &schema.EnumType{
 						T:      "status",
@@ -940,6 +940,12 @@ func TestPlanChanges(t *testing.T) {
 							),
 					)
 				return []schema.Change{
+					&schema.DropTable{
+						T: s.Tables[0],
+					},
+					&schema.DropTable{
+						T: s.Tables[1],
+					},
 					&schema.DropObject{
 						O: &schema.EnumType{
 							T:      "state",
@@ -947,12 +953,6 @@ func TestPlanChanges(t *testing.T) {
 							Schema: schema.New("public"),
 						},
 					},
-					&schema.DropTable{
-						T: s.Tables[0],
-					},
-					&schema.DropTable{
-						T: s.Tables[1],
-					},
 				}
 			}(),
 			wantPlan: &migrate.Plan{
@@ -974,6 +974,7 @@ func TestPlanChanges(t *testing.T) {
 				},
 			},
 		},
+		// Append enum value at the end.
 		{
 			changes: []schema.Change{
 				&schema.ModifyObject{
@@ -997,6 +998,93 @@ func TestPlanChanges(t *testing.T) {
 				},
 			},
 		},
+		// Append enum values at the beginning.
+		{
+			changes: []schema.Change{
+				&schema.ModifyObject{
+					From: &schema.EnumType{
+						T:      "state",
+						Values: []string{"on", "off"},
+						Schema: schema.New("public"),
+					},
+					To: &schema.EnumType{
+						T:      "state",
+						Values: []string{"unknown", "null", "on", "off"},
+						Schema: schema.New("public"),
+					},
+				},
+			},
+			wantPlan: &migrate.Plan{
+				Reversible:    false,
+				Transactional: true,
+				Changes: []*migrate.Change{
+					{Cmd: `ALTER TYPE "public"."state" ADD VALUE 'unknown' BEFORE 'on'`},
+					{Cmd: `ALTER TYPE "public"."state" ADD VALUE 'null' AFTER 'unknown'`},
+				},
+			},
+		},
+		// Append values at beginning, middle and end.
+		{
+			changes: []schema.Change{
+				&schema.ModifyObject{
+					From: &schema.EnumType{
+						T:      "state",
+						Values: []string{"on", "off", "on-off"},
+						Schema: schema.New("public"),
+					},
+					To: &schema.EnumType{
+						T:      "state",
+						Values: []string{"start", "on", "null", "off", "unknown", "on-off"},
+						Schema: schema.New("public"),
+					},
+				},
+			},
+			wantPlan: &migrate.Plan{
+				Reversible:    false,
+				Transactional: true,
+				Changes: []*migrate.Change{
+					{Cmd: `ALTER TYPE "public"."state" ADD VALUE 'start' BEFORE 'on'`},
+					{Cmd: `ALTER TYPE "public"."state" ADD VALUE 'null' AFTER 'on'`},
+					{Cmd: `ALTER TYPE "public"."state" ADD VALUE 'unknown' AFTER 'off'`},
+				},
+			},
+		},
+		// Enum reordering.
+		{
+			changes: []schema.Change{
+				&schema.ModifyObject{
+					From: &schema.EnumType{
+						T:      "state",
+						Values: []string{"on", "off"},
+						Schema: schema.New("public"),
+					},
+					To: &schema.EnumType{
+						T:      "state",
+						Values: []string{"off", "on"},
+						Schema: schema.New("public"),
+					},
+				},
+			},
+			wantErr: true,
+		},
+		// Enum value dropping.
+		{
+			changes: []schema.Change{
+				&schema.ModifyObject{
+					From: &schema.EnumType{
+						T:      "state",
+						Values: []string{"on", "off"},
+						Schema: schema.New("public"),
+					},
+					To: &schema.EnumType{
+						T:      "state",
+						Values: []string{"off"},
+						Schema: schema.New("public"),
+					},
+				},
+			},
+			wantErr: true,
+		},
 		// Modify column type and drop comment.
 		{
 			changes: []schema.Change{
