@@ -23,16 +23,17 @@ import (
 
 type (
 	doc struct {
-		Tables       []*sqlspec.Table   `spec:"table"`
-		Views        []*sqlspec.View    `spec:"view"`
-		Materialized []*sqlspec.View    `spec:"materialized"`
-		Enums        []*enum            `spec:"enum"`
-		Domains      []*domain          `spec:"domain"`
-		Sequences    []*sequence        `spec:"sequence"`
-		Funcs        []*sqlspec.Func    `spec:"function"`
-		Procs        []*sqlspec.Func    `spec:"procedure"`
-		Triggers     []*sqlspec.Trigger `spec:"trigger"`
-		Schemas      []*sqlspec.Schema  `spec:"schema"`
+		Tables       []*sqlspec.Table    `spec:"table"`
+		Views        []*sqlspec.View     `spec:"view"`
+		Materialized []*sqlspec.View     `spec:"materialized"`
+		Enums        []*enum             `spec:"enum"`
+		Domains      []*domain           `spec:"domain"`
+		Sequences    []*sqlspec.Sequence `spec:"sequence"`
+		Funcs        []*sqlspec.Func     `spec:"function"`
+		Procs        []*sqlspec.Func     `spec:"procedure"`
+		Triggers     []*sqlspec.Trigger  `spec:"trigger"`
+		Extensions   []*extension        `spec:"extension"`
+		Schemas      []*sqlspec.Schema   `spec:"schema"`
 	}
 
 	// Enum holds a specification for an enum type.
@@ -56,13 +57,12 @@ type (
 		schemahcl.DefaultExtension
 	}
 
-	// Sequence holds a specification for a sequence.
-	sequence struct {
-		Name      string         `spec:",name"`
-		Qualifier string         `spec:",qualifier"`
-		Schema    *schemahcl.Ref `spec:"schema"`
-		// Type, Start, Increment, Min, Max, Cache, Cycle
-		// are optionally added to the sequence definition.
+	// extension holds a specification for a postgres extension.
+	// Note, extension names are unique within a realm (database).
+	extension struct {
+		Name string `spec:",name"`
+		// Schema, version and comment are conditionally
+		// added to the extension definition.
 		schemahcl.DefaultExtension
 	}
 )
@@ -77,6 +77,7 @@ func (d *doc) merge(d1 *doc) {
 	d.Domains = append(d.Domains, d1.Domains...)
 	d.Schemas = append(d.Schemas, d1.Schemas...)
 	d.Sequences = append(d.Sequences, d1.Sequences...)
+	d.Extensions = append(d.Extensions, d1.Extensions...)
 	d.Triggers = append(d.Triggers, d1.Triggers...)
 	d.Materialized = append(d.Materialized, d1.Materialized...)
 }
@@ -117,22 +118,10 @@ func (d *domain) SetQualifier(q string) { d.Qualifier = q }
 // SchemaRef returns the schema reference for the domain.
 func (d *domain) SchemaRef() *schemahcl.Ref { return d.Schema }
 
-// Label returns the defaults label used for the sequence resource.
-func (s *sequence) Label() string { return s.Name }
-
-// QualifierLabel returns the qualifier label used for the sequence resource, if any.
-func (s *sequence) QualifierLabel() string { return s.Qualifier }
-
-// SetQualifier sets the qualifier label used for the sequence resource.
-func (s *sequence) SetQualifier(q string) { s.Qualifier = q }
-
-// SchemaRef returns the schema reference for the sequence.
-func (s *sequence) SchemaRef() *schemahcl.Ref { return s.Schema }
-
 func init() {
 	schemahcl.Register("enum", &enum{})
 	schemahcl.Register("domain", &domain{})
-	schemahcl.Register("sequence", &sequence{})
+	schemahcl.Register("extension", &extension{})
 }
 
 // evalSpec evaluates an Atlas DDL document into v using the input.
@@ -152,6 +141,9 @@ func evalSpec(p *hclparse.Parser, v any, input map[string]cty.Value) error {
 		if err := convertSequences(d.Tables, d.Sequences, v); err != nil {
 			return err
 		}
+		if err := convertExtensions(d.Extensions, v); err != nil {
+			return err
+		}
 		if err := normalizeRealm(v); err != nil {
 			return err
 		}
@@ -173,6 +165,7 @@ func evalSpec(p *hclparse.Parser, v any, input map[string]cty.Value) error {
 		if err := convertSequences(d.Tables, d.Sequences, r); err != nil {
 			return err
 		}
+		// Extensions are skipped in schema scope.
 		if err := normalizeRealm(r); err != nil {
 			return err
 		}
@@ -191,16 +184,16 @@ func MarshalSpec(v any, marshaler schemahcl.Marshaler) ([]byte, error) {
 		d  doc
 		ts []*schema.Trigger
 	)
-	switch s := v.(type) {
+	switch rv := v.(type) {
 	case *schema.Schema:
-		d1, trs, err := schemaSpec(s)
+		d1, trs, err := schemaSpec(rv)
 		if err != nil {
 			return nil, fmt.Errorf("specutil: failed converting schema to spec: %w", err)
 		}
 		ts = trs
 		d.merge(d1)
 	case *schema.Realm:
-		for _, s := range s.Schemas {
+		for _, s := range rv.Schemas {
 			d1, trs, err := schemaSpec(s)
 			if err != nil {
 				return nil, fmt.Errorf("specutil: failed converting schema to spec: %w", err)
@@ -208,6 +201,9 @@ func MarshalSpec(v any, marshaler schemahcl.Marshaler) ([]byte, error) {
 			d.merge(d1)
 			ts = append(ts, trs...)
 		}
+		if err := realmObjectsSpec(&d, rv); err != nil {
+			return nil, err
+		}
 		if err := specutil.QualifyObjects(d.Tables); err != nil {
 			return nil, err
 		}
@@ -232,10 +228,10 @@ func MarshalSpec(v any, marshaler schemahcl.Marshaler) ([]byte, error) {
 		if err := specutil.QualifyObjects(d.Procs); err != nil {
 			return nil, err
 		}
-		if err := specutil.QualifyReferences(d.Tables, s); err != nil {
+		if err := specutil.QualifyReferences(d.Tables, rv); err != nil {
 			return nil, err
 		}
-		if err := qualifySeqRefs(d.Sequences, d.Tables, s); err != nil {
+		if err := qualifySeqRefs(d.Sequences, d.Tables, rv); err != nil {
 			return nil, err
 		}
 	default:
