@@ -56,6 +56,8 @@ table "table" {
 	check "positive price" {
 		expr = "price > 0"
 	}
+	without_rowid = true
+	strict        = false
 }
 
 table "accounts" {
@@ -66,11 +68,10 @@ table "accounts" {
 	primary_key {
 		columns = [table.accounts.column.name]
 	}
+	strict = true
 }
 `
-	exp := &schema.Schema{
-		Name: "schema",
-	}
+	exp := schema.NewRealm(schema.New("schema")).Schemas[0]
 	exp.Tables = []*schema.Table{
 		{
 			Name:   "table",
@@ -118,6 +119,7 @@ table "accounts" {
 					Name: "positive price",
 					Expr: "price > 0",
 				},
+				&WithoutRowID{},
 			},
 		},
 		{
@@ -134,6 +136,9 @@ table "accounts" {
 					},
 				},
 			},
+			Attrs: []schema.Attr{
+				&Strict{},
+			},
 		},
 	}
 	exp.Tables[0].PrimaryKey = &schema.Index{
@@ -178,6 +183,63 @@ table "accounts" {
 	require.EqualValues(t, exp, &s)
 }
 
+func TestUnmarshalViews(t *testing.T) {
+	f := `table "t1" {
+  schema = schema.public
+  column "id" {
+    null = false
+    type = int
+  }
+}
+view "v1" {
+ schema = schema.public
+ as     = "SELECT * FROM t2 WHERE id IS NOT NULL"
+}
+view "v2" {
+  schema = schema.public
+  column "id" {
+    null = false
+    type = int
+  }
+  as      = "SELECT * FROM t3 WHERE id IS NOT NULL ORDER BY id"
+  comment = "view comment"
+}
+view "v3" {
+  schema     = schema.public
+  as         = "SELECT * FROM v2 JOIN t1 USING (id)"
+  depends_on = [view.v1, table.t1]
+}
+schema "public" {
+}
+`
+	var (
+		r   schema.Realm
+		s   schema.Schema
+		exp = schema.New("public").
+			AddTables(
+				schema.NewTable("t1").
+					AddColumns(
+						schema.NewIntColumn("id", "int"),
+					),
+			).
+			AddViews(
+				schema.NewView("v1", "SELECT * FROM t2 WHERE id IS NOT NULL"),
+				schema.NewView("v2", "SELECT * FROM t3 WHERE id IS NOT NULL ORDER BY id").
+					AddColumns(
+						schema.NewIntColumn("id", "int"),
+					).
+					SetComment("view comment"),
+			)
+	)
+	exp.AddViews(
+		schema.NewView("v3", "SELECT * FROM v2 JOIN t1 USING (id)").
+			AddDeps(exp.Views[0], exp.Tables[0]),
+	)
+	r.AddSchemas(exp)
+	require.NoError(t, EvalHCLBytes([]byte(f), &s, nil))
+	require.EqualValues(t, exp, &s)
+}
+
 func TestMarshalSpec_AutoIncrement(t *testing.T) {
 	s := &schema.Schema{
 		Name: "test",
@@ -423,6 +485,36 @@ schema "test" {
 	}
 }
 
+func TestMarshalSpec_TableOptions(t *testing.T) {
+	s := schema.New("test").
+		AddTables(
+			schema.NewTable("users").
+				AddColumns(
+					schema.NewIntColumn("id", "int"),
+				).
+				AddAttrs(
+					&WithoutRowID{},
+					&Strict{},
+				),
+		)
+	s.Tables[0].SetSchema(s)
+	buf, err := MarshalSpec(s, hclState)
+	require.NoError(t, err)
+	const expected = `table "users" {
+  schema = schema.test
+  column "id" {
+    null = false
+    type = int
+  }
+  without_rowid = true
+  strict        = true
+}
+schema "test" {
+}
+`
+	require.EqualValues(t, expected, string(buf))
+}
+
 func TestInputVars(t *testing.T) {
 	spectest.TestInputVars(t, EvalHCL)
 }
